@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: systemDb.php 880 2008-08-06 07:40:32Z fishbone $
+ * @version    SVN: $Id: systemDb.php 909 2008-08-12 07:23:06Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/baseDb.php');
@@ -389,6 +389,23 @@ class SystemDb extends BaseDb
 		$retValue = $this->selectRecords($queryStr, array($pageId, $pageSubId, $position, $setId), $rows);
 		return $retValue;
 	}
+	/**
+	 * 指定定義IDのウィジェットの参照数を取得
+	 *
+	 * @param string $widgetId		ウィジェットID
+	 * @param string $configId    	定義ID
+	 * @param int    $setId			定義セットID
+	 * @return int					参照数
+	 */
+	function getPageDefCount($widgetId, $configId, $setId = 0)
+	{
+		$queryStr  = 'select * from _page_def left join _widgets on pd_widget_id = wd_id and wd_deleted = false ';
+		$queryStr .=   'where pd_widget_id = ? ';		// ウィジェットID
+		$queryStr .=     'and pd_config_id = ? ';
+		$queryStr .=     'and pd_set_id = ? ';
+		return $this->selectRecordCount($queryStr, array($widgetId, $configId, $setId));
+	}
+	
 	/**
 	 * ウィジェットが指定のページID上にあるかどうか判断
 	 *
@@ -660,53 +677,6 @@ class SystemDb extends BaseDb
 		$ret = $this->endTransaction();
 		return $ret;
 	}
-	/**
-	 * ウィジェット表示順を変更する
-	 *
-	 * @param string $pageId		ページID
-	 * @param string $pageSubId		ページサブID
-	 * @param string $position		ポジション
-	 * @param array $widgetNoArray	ウィジェット並び順
-	 * @param int    $setId				定義セットID
-	 * @return bool				true=成功、false=失敗
-	 */
-	 /*
-	function orderWidget($pageId, $pageSubId, $position, $widgetArray, $setId = 0)
-	{
-		global $gEnvManager;
-
-		// 指定ポジションのウィジェットをすべて取得
-		$ret = $this->getPageDef($pageId, $pageSubId, $position, $rows, $setId);
-		if (!$ret) return false;
-	
-		// ウィジェット数をチェックし、異なっている場合はエラー
-		$widgetCount = count($rows);
-		if ($widgetCount != count($widgetArray)) return false;
-		
-		$now = date("Y/m/d H:i:s");	// 現在日時
-		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
-		
-		// トランザクション開始
-		$this->startTransaction();
-
-		for ($i = 0; $i < $widgetCount; $i++){
-			$serialNo = $rows[$widgetArray[$i]]['pd_serial'];
-			$index = $rows[$i]['pd_index'];
-			
-			// 既存項目を更新
-			$queryStr  = 'UPDATE _page_def ';
-			$queryStr .=   'SET ';
-			$queryStr .=     'pd_index = ?, ';
-			$queryStr .=     'pd_update_user_id = ?, ';
-			$queryStr .=     'pd_update_dt = ? ';
-			$queryStr .=   'WHERE pd_serial = ? ';
-			$this->execStatement($queryStr, array($index, $userId, $now, $serialNo));
-		}
-										
-		// トランザクション確定
-		$ret = $this->endTransaction();
-		return $ret;
-	}*/
 	/**
 	 * ウィジェットを移動する
 	 *
@@ -967,49 +937,6 @@ class SystemDb extends BaseDb
 		$ret = $this->endTransaction();
 		return $ret;
 	}
-	/**
-	 * ウィジェットを削除する
-	 *
-	 * @param string $pageId		ページID
-	 * @param string $pageSubId		ページサブID
-	 * @param string $position		ポジション
-	 * @param string $widgetId		ウィジェットID
-	 * @param int $index			ポジション内の位置
-	 * @param int $widCount;		ポジション内のウィジェット数
-	 * @param int    $setId				定義セットID
-	 * @return bool				true=成功、false=失敗
-	 */
-	 /*
-	function delWidget($pageId, $pageSubId, $position, $widget, $index, $widCount, $setId = 0)
-	{
-		global $gEnvManager;
-
-		// 指定ポジションのウィジェットをすべて取得
-		$ret = $this->getPageDef($pageId, $pageSubId, $position, $rows, $setId);
-		if (!$ret) return true;
-	
-		// 指定インデックスのエラーチェック
-		$widgetCount = count($rows);
-		if ($widgetCount != $widCount) return false;
-		if ($posIndex < 0 || $widgetCount <= $posIndex) return false;
-		
-		$serialNo = $rows[$index]['pd_serial'];
-		$widgetId = $rows[$index]['pd_widget_id'];
-		if ($widgetId != $widget) return false;
-		
-		$now = date("Y/m/d H:i:s");	// 現在日時
-		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
-		
-		// トランザクション開始
-		$this->startTransaction();
-		
-		$queryStr  = 'DELETE FROM _page_def WHERE pd_serial = ?';
-		$this->execStatement($queryStr, array($serialNo));
-		
-		// トランザクション確定
-		$ret = $this->endTransaction();
-		return $ret;
-	}*/
 	/**
 	 * ウィジェットを削除する
 	 *
@@ -1720,49 +1647,59 @@ class SystemDb extends BaseDb
 	 * @param string  $serializedParam	シリアライズしたデータ
 	 * @param int     $userId			更新者ユーザID
 	 * @param string  $now				現在日時
+	 * @param int     $configId			定義ID(-1のとき新規追加、-1以外のときは更新)
 	 * @return bool						true = 成功、false = 失敗
 	 */
-	function updateWidgetParam($widgetId, $serializedParam, $userId, $now = null)
+	function updateWidgetParam($widgetId, $serializedParam, $userId, $now = null, &$configId = 0)
 	{
 		// 更新日時が設定されていないときは設定
 		if (empty($now)) $now = date("Y/m/d H:i:s");	// 現在日時
+		$historyIndex = 0;		// 履歴番号
 		
 		// トランザクション開始
 		$this->startTransaction();
 		
-		// 前レコードの削除状態チェック
-		$historyIndex = 0;
-		$queryStr = 'SELECT * FROM _widget_param ';
-		$queryStr .=  'WHERE wp_id = ? ';
-		$queryStr .=  'ORDER BY wp_history_index DESC ';
-		$queryStr .=    'LIMIT 1';
-		$ret = $this->selectRecord($queryStr, array($widgetId), $row);
-		if ($ret){
-			$historyIndex = $row['wp_history_index'] + 1;
-		
-			// レコードが削除されていない場合は削除
-			if (!$row['wp_deleted']){
-				// 古いレコードを削除
-				$queryStr  = 'UPDATE _widget_param ';
-				$queryStr .=   'SET wp_deleted = true, ';	// 削除
-				$queryStr .=     'wp_update_user_id = ?, ';
-				$queryStr .=     'wp_update_dt = ? ';
-				$queryStr .=   'WHERE wp_serial = ?';
-				$ret = $this->execStatement($queryStr, array($userId, $now, $row['wp_serial']));
-				if (!$ret){
-					$this->endTransaction();
-					return false;
+		if ($configId >= 0){		// 更新のとき
+			// 前レコードの削除状態チェック
+			$queryStr = 'SELECT * FROM _widget_param ';
+			$queryStr .=  'WHERE wp_id = ? AND wp_config_id = ? ';
+			$queryStr .=  'ORDER BY wp_history_index DESC ';
+			$ret = $this->selectRecord($queryStr, array($widgetId, $configId), $row);
+			if ($ret){
+				$historyIndex = $row['wp_history_index'] + 1;
+	
+				// レコードが削除されていない場合は削除
+				if (!$row['wp_deleted']){
+					// 古いレコードを削除
+					$queryStr  = 'UPDATE _widget_param ';
+					$queryStr .=   'SET wp_deleted = true, ';	// 削除
+					$queryStr .=     'wp_update_user_id = ?, ';
+					$queryStr .=     'wp_update_dt = ? ';
+					$queryStr .=   'WHERE wp_serial = ?';
+					$ret = $this->execStatement($queryStr, array($userId, $now, $row['wp_serial']));
+					if (!$ret){
+						$this->endTransaction();
+						return false;
+					}
 				}
 			}
+		} else {		// 新規追加のときは定義IDを求める
+			// 定義IDは1以上を使用する
+			$newId = 1;
+			$queryStr = 'SELECT max(wp_config_id) as ms FROM _widget_param WHERE wp_id = ?';
+			$ret = $this->selectRecord($queryStr, array($widgetId), $row);
+			if ($ret) $newId = $row['ms'] + 1;
+			$configId = $newId;			// 定義IDを更新
 		}
 		
-		// データを追加
-		$queryStr = 'INSERT INTO _widget_param ';
-		$queryStr .=  '(wp_id, wp_history_index, wp_param, wp_create_user_id, wp_create_dt) ';
-		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, ?, ?)';
-		$this->execStatement($queryStr, array($widgetId, $historyIndex, $serializedParam, $userId, $now));
-			
+		if (!empty($serializedParam)){		// 設定データが空のときはデータを追加しない
+			// データを追加
+			$queryStr = 'INSERT INTO _widget_param ';
+			$queryStr .=  '(wp_id, wp_config_id, wp_history_index, wp_param, wp_create_user_id, wp_create_dt) ';
+			$queryStr .=  'VALUES ';
+			$queryStr .=  '(?, ?, ?, ?, ?, ?)';
+			$this->execStatement($queryStr, array($widgetId, $configId, $historyIndex, $serializedParam, $userId, $now));
+		}
 		// トランザクション確定
 		$ret = $this->endTransaction();
 		return $ret;
@@ -1770,15 +1707,30 @@ class SystemDb extends BaseDb
 	/**
 	 * ウィジェットパラメータ取得
 	 *
-	 * @param  string $widgetId	ウィジェットID
+	 * @param  string $widgetId			ウィジェットID
+	 * @param int     $configId			定義ID
 	 * @return string		シリアライズされたパラメータデータ
 	 */
-	function getWidgetParam($widgetId)
+	function getWidgetParam($widgetId, $configId = 0)
 	{
-		$sql = 'SELECT wp_param FROM _widget_param WHERE wp_id = ? AND wp_deleted = false';
-		$params = array($widgetId); 
+		$sql = 'SELECT wp_param FROM _widget_param WHERE wp_id = ? AND wp_config_id = ? AND wp_deleted = false';
+		$params = array($widgetId, $configId); 
 		$this->selectRecord($sql, $params, $row);
 		return $row['wp_param'];
+    }
+	/**
+	 * ウィジェットパラメータをすべて取得
+	 *
+	 * @param  string $widgetId		ウィジェットID
+	 * @param array  $rows			レコード
+	 * @return						true=1行以上取得、false=取得せず
+	 */
+	function getAllWidgetParam($widgetId, &$rows)
+	{
+		$sql = 'SELECT wp_config_id,wp_param FROM _widget_param WHERE wp_id = ? AND wp_deleted = false ORDER BY wp_config_id';
+		$params = array($widgetId); 
+		$retValue = $this->selectRecords($sql, $params, $rows);
+		return $retValue;
     }
 	/**
 	 * すべての追加クラス情報を取得
