@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: pageManager.php 934 2008-08-23 14:40:04Z fishbone $
+ * @version    SVN: $Id: pageManager.php 973 2008-09-03 02:19:35Z fishbone $
  * @link       http://www.magic3.org
  */
 class PageManager
@@ -27,7 +27,6 @@ class PageManager
 	private $defaultCssFiles;		// デフォルトで読み込むCSSファイル
 	private $defaultAdminScriptFiles;	// デフォルトで読み込むスクリプトファイル(管理用)
 	private $defaultAdminCssFiles;		// デフォルトで読み込むCSSファイル(管理用)
-	private $defaultAjaxLibFile;	// デフォルトのAjax用ライブラリファイル
 	private $pageDefPosition;		// 現在取得しているページ定義のポジション
 	private $pageDefRows;			// ページ定義レコード
 	private $useHelp = true;		// 標準ヘルプ機能を使用するかどうか
@@ -37,10 +36,14 @@ class PageManager
 	private $viewPositions = array();	// テンプレート上のポジション
 	private $viewPosId = array();		// テンプレート上のポジションのタグID
 	private $updateParentWindow;		// 親ウィンドウを再描画するかどうか
+	private $updateDefSerial;			// 更新する項目のページ定義シリアル番号
 	private $useMootools;				// MootoolsをPrototypeの代わりに使用するかどうか
 	private $headDescription;				// HTMLヘッダ「description」に出力する文字列
 	private $headKeywords;				// HTMLヘッダ「keywords」に出力する文字列
-	private $headCss = array();					// HTMLヘッダにCSS出力する文字列
+	private $headCss = array();			// HTMLヘッダにCSS出力する文字列
+	private $headScript = array();		// HTMLヘッダにJavascript出力する文字列
+	private $lastHeadCss;				// 最後に設定したHTMLヘッダにCSS出力する文字列
+	private $lastHeadScript;			// 最後に設定したHTMLヘッダにJavascript出力する文字列
 	private $outputHead;				// HTMLヘッダ出力を行ったかどうか
 	private $libFiles;					// javascript追加用ライブラリ
 	private $pageDefRev = 234;				// 画面定義のリビジョン番号
@@ -74,6 +77,7 @@ class PageManager
 	const LIB_JQUERY_THICKBOX	= 'jquery.thickbox';
 	const LIB_JQUERY_JSHOTKEYS	= 'jquery.jshotkeys';
 	const LIB_JQUERY_CYCLE		= 'jquery.cycle';
+	const LIB_JQUERY_CODEPRESS	= 'jquery.codepress';
 	const LIB_JQUERY_UI_PLUS	= 'jquery-ui-plus';
 	const LIB_FCKEDITOR			= 'fckeditor';
 	
@@ -87,7 +91,8 @@ class PageManager
 	const JQUERY_THICKBOX_CSS		= 'jquery/thickbox.css';
 	const JQUERY_JSHOTKEYS_FILENAME	= 'jquery/jquery.hotkeys.js';
 	const JQUERY_CYCLE_FILENAME		= 'jquery/jquery.cycle.all.pack.js';
-	
+	const JQUERY_CODEPRESS_FILENAME		= 'jquery/jquery.Codepress.js';
+		
 	// ファイル名
 	const MOOTOOLS_FILENAME			= 'mootools-release-1.11.js';			// mootools
 	const JQUERY_FILENAME			= 'jquery-1.2.6.pack.js';						// JQuery
@@ -99,8 +104,8 @@ class PageManager
 	const FCKEDITOR_CONFIG			= 'm3/fckconfig.js';		// FCKEditor
 
 	// Magic3用スクリプト
-	const M3_ADMIN_SCRIPT_FILENAME			= 'm3admin1.1.5.js';				// 管理機能用スクリプト
-	const M3_ADMIN_WIDGET_SCRIPT_FILENAME	= 'm3admin_widget1.1.js';	// 管理機能(ウィジェット操作)用スクリプト
+	const M3_ADMIN_SCRIPT_FILENAME			= 'm3admin1.1.6.js';				// 管理機能用スクリプト
+	const M3_ADMIN_WIDGET_SCRIPT_FILENAME	= 'm3admin_widget1.2.js';	// 管理機能(ウィジェット操作)用スクリプト
 	const M3_ADMIN_WIDGET_CSS_FILE			= '/m3/widget.css';			// 管理機能(ウィジェット操作)用CSSファイル
 	const M3_STD_SCRIPT_FILENAME			= 'm3std1.3.1.js';
 	const M3_AJAX_SCRIPT_FILENAME			= 'm3ajax1.1.js';
@@ -125,6 +130,7 @@ class PageManager
 		$this->defaultAdminScriptFiles = array(self::JQUERY_FILENAME,			// jQuery
 											self::JQUERY_UI_CORE_FILENAME,		// jQuery UI Core
 											//self::JQUERY_UI_PLUS_FILENAME,		// jQuery UI Plus
+											self::JQUERY_JSHOTKEYS_FILENAME,		// jquery.js-hotkeys
 											self::JQUERY_CONTEXTMENU_FILENAME,		// jQuery Contextmenu Lib
 											//self::FCKEDITOR_FILENAME,			// FCKEditor
 											self::M3_STD_SCRIPT_FILENAME,
@@ -141,7 +147,8 @@ class PageManager
 								self::LIB_JQUERY_THICKBOX	=>	array(	'script' => array(self::JQUERY_THICKBOX_FILENAME),// jquery.thickbox用のファイル
 																		'css'	=> array(self::JQUERY_THICKBOX_CSS)),
 								self::LIB_JQUERY_JSHOTKEYS	=>	array(	'script' => array(self::JQUERY_JSHOTKEYS_FILENAME)),	// jquery.js-hotkeys用のファイル
-								self::LIB_JQUERY_CYCLE		=>	array(	'script' => array(self::JQUERY_CYCLE_FILENAME)));		// jquery.cycle用のファイル
+								self::LIB_JQUERY_CYCLE		=>	array(	'script' => array(self::JQUERY_CYCLE_FILENAME)),		// jquery.cycle用のファイル
+								self::LIB_JQUERY_CODEPRESS	=>	array(	'script' => array(self::JQUERY_CODEPRESS_FILENAME)));		// jquery.codepress用のファイル
 
 		// 遅延ウィジェットリスト									
 		$this->lateLaunchWidgetList = array();
@@ -193,7 +200,26 @@ class PageManager
 	function addHeadCss($css)
 	{
 		$destCss = trim($css);
-		if (!empty($destCss)) $this->headCss[] = $css;
+		if (!empty($destCss)){
+			if (!in_array($css, $this->headCss)) $this->headCss[] = $css;
+			
+			$this->lastHeadCss = $css;			// 最後に設定したHTMLヘッダにCSS出力する文字列
+		}
+	}
+	/**
+	 * HTMLヘッダに出力するJavascriptの文字列を設定
+	 *
+	 * @param string $script	追加するJavascript内容
+	 * @return 					なし
+	 */
+	function addHeadScript($script)
+	{
+		$destScript = trim($script);
+		if (!empty($destScript)){
+			if (!in_array($script, $this->headScript)) $this->headScript[] = $script;
+			
+			$this->lastHeadScript = $script;			// 最後に設定したHTMLヘッダにJavascript出力する文字列
+		}
 	}
 	/**
 	 * 表示ポジションを表示するかどうか
@@ -259,11 +285,13 @@ class PageManager
 	/**
 	 * 親ウィンドウを再描画
 	 *
-	 * @return 				なし
+	 * @param int $defSerial	ページ定義シリアル番号
+	 * @return 					なし
 	 */
-	function updateParentWindow()
+	function updateParentWindow($defSerial = 0)
 	{
 		$this->updateParentWindow = true;
+		$this->updateDefSerial = $defSerial;			// 更新する項目のページ定義シリアル番号
 	}
 	/**
 	 * CSSファイルの追加
@@ -296,7 +324,7 @@ class PageManager
 	function addScriptFile($path)
 	{
 		$destPath = trim($path, '/');
-		if (!in_array($destPath, $this->defaultScriptFiles)) $this->defaultScriptFiles[] = $destPath;
+		if (!empty($destPath) && !in_array($destPath, $this->defaultScriptFiles)) $this->defaultScriptFiles[] = $destPath;
 	}
 	/**
 	 * JavaScriptファイルの追加
@@ -494,6 +522,10 @@ class PageManager
 			for ($i = 0; $i < $count; $i++){
 				list($wId, $index, $confId, $preId, $serial) = $this->latelaunchWidgetParam[$i];
 				if ($wId == $widgetId){
+					// パラメータ初期化
+					$this->lastHeadCss = '';			// 最後に設定したHTMLヘッダにCSS出力する文字列
+					$this->lastHeadScript = '';			// 最後に設定したHTMLヘッダにJavascript出力する文字列
+					
 					// バッファ作成
 					ob_start();
 
@@ -718,6 +750,11 @@ class PageManager
 					// 画面定義のリビジョン番号
 					$contents .= 'var M3_REVISION=' . $this->pageDefRev . ';' . M3_NL;
 				
+					// 更新用関数追加
+					$contents .= 'function m3UpdateByConfig(serial){' . M3_NL;
+					$contents .= '    window.m3.m3UpdateByConfig(serial);' . M3_NL;
+					$contents .= '}' . M3_NL;
+					
 					// 携帯用テンプレートのときは、プレビューウィンドウの更新を通知する
 					/*if ($gEnvManager->getCurrentTemplateType() == 1){
 						$contents .= 'if (window.parent.m3UpdateByChildWindow) window.parent.m3UpdateByChildWindow();' . M3_NL;
@@ -773,7 +810,7 @@ class PageManager
 			
 			// HTMLのヘッダ部(headタグ内)出力
 			$this->getHeader();
-			
+
 			// ウィジェットのJavascriptを読み込む
 			$widgetId = $gEnvManager->getCurrentWidgetId();		// カレントのウィジェットID
 			
@@ -853,7 +890,7 @@ class PageManager
 					echo '<!--' . M3_NL;
 					echo '$(function(){' . M3_NL;
 					//echo 'm3UpdateParentWindow();' . M3_NL;
-					echo 'm3UpdateParentWindowByConfig();' . M3_NL;
+					echo 'm3UpdateParentWindowByConfig(' . $this->updateDefSerial . ');' . M3_NL;// 更新する項目のページ定義シリアル番号
 					echo '});' . M3_NL;
 					echo '// -->' . M3_NL;
 					echo '</SCRIPT>' . M3_NL;
@@ -1005,7 +1042,7 @@ class PageManager
 		} else {			// 通常画面
 			// Ajaxライブラリを使用しているウィジェットがあるときは追加
 			if ($this->db->isExistsWidgetWithAjax($gEnvManager->getCurrentPageId(), $gEnvManager->getCurrentPageSubId())){
-				$this->addScriptFile($this->defaultAjaxLibFile);		// デフォルトAjaxライブラリ追加
+				$this->addScriptFile(self::JQUERY_FILENAME);		// デフォルトAjaxライブラリ追加
 				$this->addScriptFile(self::M3_AJAX_SCRIPT_FILENAME);	// Magic3のAjaxライブラリ追加
 			}
 				
@@ -1298,7 +1335,7 @@ class PageManager
 					echo '</dl>' . M3_NL;
 				}
 			}
-		} else if ($task == 'wdelete' || $task == 'wtoggle' || $task == 'wadd' || $task == 'wmove'){	// ウィジェット削除,ウィジェット共通属性変更、ウィジェット追加、ウィジェット移動のとき
+		} else if ($task == 'wget' || $task == 'wdelete' || $task == 'wtoggle' || $task == 'wadd' || $task == 'wmove'){	// ウィジェット再取得、ウィジェット削除,ウィジェット共通属性変更、ウィジェット追加、ウィジェット移動のとき
 			$rev	= $request->trimValueOf('rev');			// リビジョン
 			$serial = $request->trimValueOf('serial');
 			$position = $request->trimValueOf('pos');
@@ -1511,6 +1548,10 @@ class PageManager
 				$postpend = ($style == 1) ? "</td>\n" : '';
 				echo $prepend;
 			
+				// パラメータ初期化
+				$this->lastHeadCss = '';			// 最後に設定したHTMLヘッダにCSS出力する文字列
+				$this->lastHeadScript = '';			// 最後に設定したHTMLヘッダにJavascript出力する文字列
+	
 				// ウィジェットの前出力
 				echo $gDesignManager->getAdditionalWidgetOutput(true);
 				
