@@ -2,8 +2,8 @@
 // 直接アクセスの防止
 defined('M3_SYSTEM') or die('Access error: Direct access denied.');
 ?>
-<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
-<html>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml">
 <head><title>管理画面</title>
 <?php mosShowHead(); ?>
 <link href="<?php echo $mosConfig_live_site; ?>/templates/_admin/css/style.css" rel="stylesheet" type="text/css"/>
