@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installInitdbWidgetContainer.php 542 2008-04-25 07:59:39Z fishbone $
+ * @version    SVN: $Id: _installInitdbWidgetContainer.php 948 2008-08-28 12:26:33Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -23,6 +23,7 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 	private $createTableScripts = array();
 	const SERVER_ID = 'server_id';
 	const INSTALL_DT = 'install_dt';		// システムインストール日時
+	const WORK_DIR = 'work_dir';			// 一時ディレクトリ
 
 	/**
 	 * コンストラクタ
@@ -39,15 +40,26 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 		$this->sysDb = $gInstanceManager->getSytemDbObject();
 		
 		// 実行SQLスクリプトファイルの定義
-		$this->createTableScripts[0]['filename']		= 'mysql_create_base.sql';		// ファイル名
-		$this->createTableScripts[0]['name']			= 'システム基本テーブル';		// 表示名
-		$this->createTableScripts[0]['description']	= 'システムで最小限必要なテーブルの構築';		// 説明
-		$this->createTableScripts[1]['filename']		= 'mysql_create_standard.sql';		// ファイル名
-		$this->createTableScripts[1]['name']			= 'システム標準テーブル';		// 表示名
-		$this->createTableScripts[1]['description']	= 'システムを通常使用するのに必要なテーブルの構築';		// 説明
-		$this->createTableScripts[2]['filename']		= 'mysql_create_ec.sql';		// ファイル名
-		$this->createTableScripts[2]['name']			= 'Eコマース用テーブル';		// 表示名
-		$this->createTableScripts[2]['description']	= 'Eコマース用テーブルの構築';		// 説明
+		$i = 0;
+		$this->createTableScripts[$i]['filename']		= 'mysql_create_base.sql';		// ファイル名
+		$this->createTableScripts[$i]['name']			= 'システム基本テーブル作成';		// 表示名
+		$this->createTableScripts[$i]['description']		= 'システムで最小限必要なテーブルの作成';		// 説明
+		$i++;
+		$this->createTableScripts[$i]['filename']		= 'mysql_insert_base.sql';		// ファイル名
+		$this->createTableScripts[$i]['name']			= 'システム基本データ登録';		// 表示名
+		$this->createTableScripts[$i]['description']		= 'システムで最小限必要なデータの登録';		// 説明
+		$i++;
+		$this->createTableScripts[$i]['filename']		= 'mysql_create_standard.sql';		// ファイル名
+		$this->createTableScripts[$i]['name']			= 'システム標準テーブル作成';		// 表示名
+		$this->createTableScripts[$i]['description']		= 'システムを通常使用するのに必要なテーブルの作成';		// 説明
+		$i++;
+		$this->createTableScripts[$i]['filename']		= 'mysql_insert_standard.sql';		// ファイル名
+		$this->createTableScripts[$i]['name']			= 'システム標準データ登録';		// 表示名
+		$this->createTableScripts[$i]['description']		= 'システムを通常使用するのに必要なデータの登録';		// 説明
+		$i++;
+		$this->createTableScripts[$i]['filename']		= 'mysql_create_ec.sql';		// ファイル名
+		$this->createTableScripts[$i]['name']			= 'Eコマース用テーブル';		// 表示名
+		$this->createTableScripts[$i]['description']		= 'Eコマース用テーブルの作成';		// 説明
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -92,6 +104,8 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 			$now = date("Y/m/d H:i:s");	// 現在日時
 			if ($ret) $ret = $this->sysDb->updateSystemConfig(self::SERVER_ID, $serverId);
 			if ($ret) $ret = $this->sysDb->updateSystemConfig(self::INSTALL_DT, $now);
+			if ($ret) $ret = $this->sysDb->updateSystemConfig(self::WORK_DIR, M3_SYSTEM_WORK_DIR_PATH);// 一時ディレクトリ
+			
 			/*
 			// DB初期化実行
 			if ($type == 'base'){
