@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainConfigsysWidgetContainer.php 542 2008-04-25 07:59:39Z fishbone $
+ * @version    SVN: $Id: admin_mainConfigsysWidgetContainer.php 948 2008-08-28 12:26:33Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -29,6 +29,7 @@ class admin_mainConfigsysWidgetContainer extends BaseWidgetContainer
 	const SITE_IN_PUBLIC = 'site_in_public';			// サイト公開状況
 	const SITE_ACCESS_EXCEPTION_IP = 'site_access_exception_ip';		// アクセス制御、例外とするIP
 	const INSTALL_DT = 'install_dt';		// システムインストール日時
+	const WORK_DIR = 'work_dir';			// 作業ディレクトリ
 	
 	/**
 	 * コンストラクタ
@@ -77,6 +78,7 @@ class admin_mainConfigsysWidgetContainer extends BaseWidgetContainer
 		$scriptCacheInBrowser = ($request->trimValueOf('item_script_cache_in_browser') == 'on') ? 1 : 0;		// ブラウザにスクリプトのキャッシュを保持するかどうか
 		//$menubarAlwaysVisible = ($request->trimValueOf('item_menubar_always_visible') == 'on') ? 1 : 0;		// 管理機能メニューバーを常時表示するかどうか
 		$lang = $request->trimValueOf('item_lang');
+		$workDir = $request->trimValueOf('item_work_dir');
 		if ($act == 'update'){		// 設定更新のとき
 			$isErr = false;
 			if (!$isErr && !empty($lang)){
@@ -91,9 +93,11 @@ class admin_mainConfigsysWidgetContainer extends BaseWidgetContainer
 			if (!$isErr){
 				if (!$this->db->updateSystemConfig(self::SCRIPT_CACHE_IN_BROWSER, $scriptCacheInBrowser)) $isErr = true;
 			}
-			//if (!$isErr){
-			//	if (!$this->db->updateSystemConfig(self::MENUBAR_ALWAYS_VISIBLE, $menubarAlwaysVisible)) $isErr = true;
-			//}
+			if (!$isErr){
+				// 最後の「/」を除く
+				$workDir = rtrim($workDir, '/');
+				if (!$this->db->updateSystemConfig(self::WORK_DIR, $workDir)) $isErr = true;
+			}
 			
 			if ($isErr){
 				$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
@@ -108,6 +112,7 @@ class admin_mainConfigsysWidgetContainer extends BaseWidgetContainer
 			$canDetailConfig	= $this->db->getSystemConfig(self::CAN_DETAIL_CONFIG);
 			$regenerateSession	= $this->db->getSystemConfig(self::REGENERATE_SESSION);
 			$scriptCacheInBrowser = $this->db->getSystemConfig(self::SCRIPT_CACHE_IN_BROWSER);
+			$workDir = $this->db->getSystemConfig(self::WORK_DIR);
 		//	$menubarAlwaysVisible = $this->db->getSystemConfig(self::MENUBAR_ALWAYS_VISIBLE);
 			
 			// メニュー項目の制御
@@ -136,6 +141,7 @@ class admin_mainConfigsysWidgetContainer extends BaseWidgetContainer
 			$canDetailConfig	= $this->db->getSystemConfig(self::CAN_DETAIL_CONFIG);
 			$regenerateSession	= $this->db->getSystemConfig(self::REGENERATE_SESSION);
 			$scriptCacheInBrowser = $this->db->getSystemConfig(self::SCRIPT_CACHE_IN_BROWSER);
+			$workDir				= $this->db->getSystemConfig(self::WORK_DIR);
 		//	$menubarAlwaysVisible = $this->db->getSystemConfig(self::MENUBAR_ALWAYS_VISIBLE);
 		}
 		// 言語選択メニューを作成
@@ -240,6 +246,13 @@ class admin_mainConfigsysWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget", "dns_resolv", $dnsResolv);
 		$this->tmpl->addVar("_widget", "server_id", $this->db->getSystemConfig(self::SERVER_ID));
 		$this->tmpl->addVar("_widget", "install_dt", $this->db->getSystemConfig(self::INSTALL_DT));		// インストール日時
+		$this->tmpl->addVar("_widget", "work_dir", $workDir);		// 一時ディレクトリ
+		if (is_writable($workDir)){
+			$data = '<b><font color="green">書き込み可能</font></b>';
+		} else {
+			$data = '<b><font color="red">書き込み不可</font></b>';
+		}
+		$this->tmpl->addVar("_widget","work_dir_access", $data);		// 一時ディレクトリの書き込み権限
 		
 		// phpinfo出力へのURL
 		//$phpinfoUrl = '?task=phpinfo&menu=off';			// メニューは非表示にする
