@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainTopWidgetContainer.php 357 2008-03-04 06:32:30Z fishbone $
+ * @version    SVN: $Id: admin_mainTopWidgetContainer.php 977 2008-09-03 08:19:30Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -149,6 +149,9 @@ class admin_mainTopWidgetContainer extends BaseWidgetContainer
 			$this->tmpl->addVar("showimage", "toppage_img", $toppageImg);
 			$this->tmpl->setAttribute('showimage', 'visibility', 'visible');
 		}
+		
+		// 管理用URL設定
+		$this->tmpl->addVar("_widget", "admin_url", $gEnvManager->getDefaultAdminUrl());
 	}
 }
 ?>
