@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainWidgetContainer.php 735 2008-06-11 07:56:42Z fishbone $
+ * @version    SVN: $Id: admin_mainWidgetContainer.php 957 2008-08-29 09:30:07Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -58,7 +58,7 @@ class admin_mainWidgetContainer extends BaseWidgetContainer
 					// 表示画面を決定
 					$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
 					$taskSrc = $task;
-					if (empty($task)){
+					if (empty($task)){	// デフォルト値
 						$task = 'top';
 					} else if ($task == 'userlist_detail'){		// ユーザ詳細
 						$task = 'userlist';
@@ -68,9 +68,6 @@ class admin_mainWidgetContainer extends BaseWidgetContainer
 					} else if ($task == 'edittable' ||		// テーブルデータ編集一覧
 								$task == 'edittable_detail'){		// テーブルデータ編集詳細
 						$task = 'edittable';
-					} else if ($task == 'menu' ||		// メニュー編集一覧
-								$task == 'menu_detail'){		// メニュー編集詳細
-						$task = 'menu';
 					}
 					
 					// オプション表示
@@ -98,7 +95,7 @@ class admin_mainWidgetContainer extends BaseWidgetContainer
 					//	case 'phpinfo':		// phpinfoを出力
 						case 'createtable':		// テーブル作成
 						case 'edittable':		// テーブル編集
-						case 'menu':		// メニュー編集
+						case 'editmenu':		// メニュー編集
 							$gLaunchManager->goSubWidget($task);
 							return false;
 						case 'logout':		// ログアウト処理
